==> pvfs2-0.0.1.tar.gz: pvfs2-0.0.1/test/server/showconfig.c <==
#include <stdio.h>
#include <string.h>
#include "trove.h"
#include "pvfs2-storage.h"
#include "dotconf.h"
#include "server-config.h"
#include "gossip.h"


void print_filesystem_configuration(struct filesystem_configuration_s *fs)
{
    struct llist *cur = NULL;
    struct host_handle_mapping_s *cur_h_mapping = NULL;

    if (fs)
    {
        fprintf(stderr,"File system name: %s\n",fs->file_system_name);
        fprintf(stderr,"FS Collection ID: %d\n",fs->coll_id);
        fprintf(stderr,"FS Root Handle  : %Ld\n",fs->root_handle);

        fprintf(stderr,"\t--- Meta Server(s) for %s (%d total):\n",
                fs->file_system_name,llist_count(fs->meta_handle_ranges));
        cur = fs->meta_handle_ranges;
        while(cur)
        {
            cur_h_mapping = llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s\n",
                    cur_h_mapping->alias_mapping->host_alias);
            cur = llist_next(cur);
        }

        fprintf(stderr,"\t--- Data Server(s) for %s (%d total):\n",
                fs->file_system_name,llist_count(fs->data_handle_ranges));
        cur = fs->data_handle_ranges;
        while(cur)
        {
            cur_h_mapping = llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s\n",
                    cur_h_mapping->alias_mapping->host_alias);
            cur = llist_next(cur);
        }

        fprintf(stderr,"\t--- Meta Handle Mappings for %s:\n",
                fs->file_system_name);
        cur = fs->meta_handle_ranges;
        while(cur)
        {
            cur_h_mapping = llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s has handle range %s\n",
                    cur_h_mapping->alias_mapping->host_alias,
                    cur_h_mapping->handle_range);
            cur = llist_next(cur);
        }

        fprintf(stderr,"\t--- Data Handle Mappings for %s:\n",
                fs->file_system_name);
        cur = fs->data_handle_ranges;
        while(cur)
        {
            cur_h_mapping = llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s has handle range %s\n",
                    cur_h_mapping->alias_mapping->host_alias,
                    cur_h_mapping->handle_range);
            cur = llist_next(cur);
        }
    }
}

int main(int argc, char **argv)
{
    struct llist *cur = NULL;
    struct server_configuration_s serverconfig;
    struct host_alias_s *cur_alias;
    struct filesystem_configuration_s *cur_fs = NULL;

    if (argc != 3)
    {
        printf("Usage: %s <fs.conf> <server.conf>\n",argv[0]);
        return 1;
    }

    gossip_enable_stderr();

    memset(&serverconfig,0,sizeof(serverconfig));
    if (PINT_parse_config(&serverconfig, argv[1], argv[2]))
    {
        printf("Failed to parse config files\n");
        return 1;
    }

    /* dump all gathered config values */
    fprintf(stderr,"--- Printing filesystem configuration\n\n");

    fprintf(stderr,"server id                : %s\n",
            serverconfig.host_id);
    fprintf(stderr,"storage space            : %s\n",
            serverconfig.storage_path);
    fprintf(stderr,"fs config file name      : %s\n",
            serverconfig.fs_config_filename);
    fprintf(stderr,"fs config file length    : %d\n",
            (int)serverconfig.fs_config_buflen);
    fprintf(stderr,"server config file name  : %s\n",
            serverconfig.server_config_filename);
    fprintf(stderr,"server config file length: %d\n",
            (int)serverconfig.server_config_buflen);
    fprintf(stderr,"initial unexp requests   : %d\n",
            serverconfig.initial_unexpected_requests);
    fprintf(stderr,"configured log file      : %s\n",
            serverconfig.logfile);
    fprintf(stderr,"event logging mask string: %s\n",
            serverconfig.event_logging);

    fprintf(stderr,"\n--- Host Aliases:\n");
    cur = serverconfig.host_aliases;
    while(cur)
    {
        cur_alias = llist_head(cur);
        if (!cur_alias)
        {
            break;
        }

        fprintf(stderr,"  %s maps to %s\n",
                cur_alias->host_alias,
                cur_alias->bmi_address);
        cur = llist_next(cur);
    }

    cur = serverconfig.file_systems;
    while(cur)
    {
        cur_fs = llist_head(cur);
        if (!cur_fs)
        {
            break;
        }
        print_filesystem_configuration(cur_fs);
        cur = llist_next(cur);
    }

    fprintf(stderr,"\n--- Analyzing filesystem configuration\n\n");
    if (PINT_config_is_valid_configuration(&serverconfig))
    {
        fprintf(stderr,"\nOK: Configuration file is VALID\n");
    }
    else
    {
        fprintf(stderr,"\nERROR: Configuration file is INVALID\n");
    }

    PINT_config_release(&serverconfig);

    gossip_disable();
    return 0;
}

/*
 * Local variables:
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 *
 * vim: ts=8 sts=4 sw=4 noexpandtab
 */

==> pvfs2-0.0.8.tar.gz: pvfs2-0.0.8/test/server/showconfig.c <==
/*
 * (C) 2001 Clemson University and The University of Chicago
 *
 * See COPYING in top-level directory.
 */

#include <stdio.h>
#include <string.h>
#include "trove.h"
#include "pvfs2-storage.h"
#include "dotconf.h"
#include "server-config.h"
#include "gossip.h"

void print_filesystem_configuration(struct filesystem_configuration_s *fs);

int main(int argc, char **argv)
{
    PINT_llist *cur = NULL;
    struct server_configuration_s serverconfig;
    struct host_alias_s *cur_alias;
    struct filesystem_configuration_s *cur_fs = NULL;

    if (argc != 3)
    {
        printf("Usage: %s <fs.conf> <server.conf>\n",argv[0]);
        return 1;
    }

    gossip_enable_stderr();

    memset(&serverconfig,0,sizeof(serverconfig));
    if (PINT_parse_config(&serverconfig, argv[1], argv[2]))
    {
        printf("Failed to parse config files\n");
        return 1;
    }

    /* dump all gathered config values */
    fprintf(stderr,"--- Printing filesystem configuration\n\n");

    fprintf(stderr,"server id                : %s\n",
            serverconfig.host_id);
    fprintf(stderr,"storage space            : %s\n",
            serverconfig.storage_path);
    fprintf(stderr,"fs config file name      : %s\n",
            serverconfig.fs_config_filename);
    fprintf(stderr,"fs config file length    : %d\n",
            (int)serverconfig.fs_config_buflen);
    fprintf(stderr,"server config file name  : %s\n",
            serverconfig.server_config_filename);
    fprintf(stderr,"server config file length: %d\n",
            (int)serverconfig.server_config_buflen);
    fprintf(stderr,"initial unexp requests   : %d\n",
            serverconfig.initial_unexpected_requests);
    fprintf(stderr,"configured log file      : %s\n",
            serverconfig.logfile);
    fprintf(stderr,"event logging mask string: %s\n",
            serverconfig.event_logging);

    fprintf(stderr,"\n--- Host Aliases:\n");
    cur = serverconfig.host_aliases;
    while(cur)
    {
        cur_alias = PINT_llist_head(cur);
        if (!cur_alias)
        {
            break;
        }

        fprintf(stderr,"  %s maps to %s\n",
                cur_alias->host_alias,
                cur_alias->bmi_address);
        cur = PINT_llist_next(cur);
    }

    cur = serverconfig.file_systems;
    while(cur)
    {
        cur_fs = PINT_llist_head(cur);
        if (!cur_fs)
        {
            break;
        }
        print_filesystem_configuration(cur_fs);
        cur = PINT_llist_next(cur);
    }

    fprintf(stderr,"\n--- Analyzing filesystem configuration\n\n");
    if (PINT_config_is_valid_configuration(&serverconfig))
    {
        fprintf(stderr,"\nOK: Configuration file is VALID\n");
    }
    else
    {
        fprintf(stderr,"\nERROR: Configuration file is INVALID\n");
    }

    PINT_config_release(&serverconfig);

    gossip_disable();
    return 0;
}

void print_filesystem_configuration(struct filesystem_configuration_s *fs)
{
    PINT_llist *cur = NULL;
    struct host_handle_mapping_s *cur_h_mapping = NULL;

    if (fs)
    {
        fprintf(stderr,"File system name: %s\n",fs->file_system_name);
        fprintf(stderr,"FS Collection ID: %d\n",fs->coll_id);
        fprintf(stderr,"FS Root Handle  : %Lu\n",Lu(fs->root_handle));

        fprintf(stderr,"\t--- Meta Server(s) for %s (%d total):\n",
                fs->file_system_name,PINT_llist_count(fs->meta_handle_ranges));
        cur = fs->meta_handle_ranges;
        while(cur)
        {
            cur_h_mapping = PINT_llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s\n",
                    cur_h_mapping->alias_mapping->host_alias);
            cur = PINT_llist_next(cur);
        }

        fprintf(stderr,"\t--- Data Server(s) for %s (%d total):\n",
                fs->file_system_name,PINT_llist_count(fs->data_handle_ranges));
        cur = fs->data_handle_ranges;
        while(cur)
        {
            cur_h_mapping = PINT_llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s\n",
                    cur_h_mapping->alias_mapping->host_alias);
            cur = PINT_llist_next(cur);
        }

        fprintf(stderr,"\t--- Meta Handle Mappings for %s:\n",
                fs->file_system_name);
        cur = fs->meta_handle_ranges;
        while(cur)
        {
            cur_h_mapping = PINT_llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s has handle range %s\n",
                    cur_h_mapping->alias_mapping->host_alias,
                    cur_h_mapping->handle_range);
            cur = PINT_llist_next(cur);
        }

        fprintf(stderr,"\t--- Data Handle Mappings for %s:\n",
                fs->file_system_name);
        cur = fs->data_handle_ranges;
        while(cur)
        {
            cur_h_mapping = PINT_llist_head(cur);
            if (!cur_h_mapping)
            {
                break;
            }
            fprintf(stderr,"\t  %s has handle range %s\n",
                    cur_h_mapping->alias_mapping->host_alias,
                    cur_h_mapping->handle_range);
            cur = PINT_llist_next(cur);
        }
    }
}

/*
 * Local variables:
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 *
 * vim: ts=8 sts=4 sw=4 noexpandtab
 */
